Crate livekit_datatrack

Crate livekit_datatrack 

LiveKit Data Track

Important: This is an internal crate that powers the data tracks feature in LiveKit client SDKs (including Rust and others) and is not usable directly.

To use data tracks in your application, please use the public APIs provided by the client SDKs.

Modules

api
Public APIs re-exported by client SDKs.
backend
Internal APIs used within client SDKs to power data tracks functionality.