Module api

Module api 

Public APIs re-exported by client SDKs.

Structs

DataTrack
Track for communicating application-specific data between participants in room.
DataTrackFrame
A frame published on a data track, consisting of a payload and optional metadata.
DataTrackInfo
Information about a published data track.
DataTrackOptions
Options for publishing a data track.
DataTrackSid
SFU-assigned identifier uniquely identifying a data track.
DataTrackSidError
DataTrackStream
A stream of DataTrackFrames received from a RemoteDataTrack.
DataTrackSubscribeOptions
Options for subscribing to a data track.
InternalError
Internal data track error.
Local
Marker type indicating a DataTrack belongs to the local participant.
PushFrameError
Frame could not be pushed to a data track.
Remote
Marker type indicating a DataTrack belongs to a remote participant.

Enums

DataTrackSubscribeError
PublishError
An error that can occur when publishing a data track.
PushFrameErrorReason
Reason why a data track frame could not be pushed.

Type Aliases

LocalDataTrack
Data track published by the local participant.
RemoteDataTrack
Data track published by a remote participant.