#[non_exhaustive]pub enum DataTrackFrameEncoding {
Ros1,
Cdr,
Protobuf,
Flatbuffer,
Cbor,
Msgpack,
Json,
Other,
Custom(String),
}Expand description
Encoding used for frames pushed on a data track.
The serialization format of the frame bytes (e.g. Protobuf); the structure
of those bytes is described by a schema, see DataTrackSchemaEncoding.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Ros1
ROS 1, must be described by a Ros1Msg schema.
Cdr
Protobuf
Protocol Buffer, must be described by a Protobuf schema.
Flatbuffer
FlatBuffer, must be described by a Flatbuffer schema.
Cbor
CBOR, self-describing.
Msgpack
MessagePack, self-describing.
Json
JSON, self-describing or described by a JsonSchema schema.
Other
Another well-known encoding not known to this client version.
Custom(String)
An application-specific encoding identified by the contained string.
Prefer using one of the well-known encodings unless the format is not enumerated. The identifier must be non-empty and not exceed the server’s length limit.