pub enum DataTrackSchemaError {
MissingFrameEncoding,
MissingSchemaId,
Incompatible,
}Expand description
An error that can occur when validating data track schema metadata.
Variants
MissingFrameEncoding
Frame encoding is required when providing schema ID.
MissingSchemaId
Schema ID is required for frame encoding that is not self-describing.
Incompatible
Specified schema and frame encodings are incompatible.