pub enum PublishError {
NotAllowed,
DuplicateName,
InvalidName,
Timeout,
LimitReached,
Disconnected,
Internal(InternalError),
}Expand description
An error that can occur when publishing a data track.
Variants
NotAllowed
Local participant does not have permission to publish data tracks.
Ensure the participant’s token contains the canPublishData grant.
DuplicateName
A track with the same name is already published by the local participant.
InvalidName
The track name is invalid.
This occurs when the name is empty or exceeds the allowed maximum length.
Timeout
Request to publish the track took long to complete.
LimitReached
No additional data tracks can be published by the local participant.
Disconnected
Cannot publish data track when the room is disconnected.
Internal(InternalError)
Internal error, please report on GitHub.