pub enum PushFrameErrorReason {
TrackUnpublished,
QueueFull,
}Expand description
Reason why a data track frame could not be pushed.
Variants
TrackUnpublished
Track is no longer published.
QueueFull
Frame was dropped due to the pipeline queue being full.