DataTrackFrame

Struct DataTrackFrame 

pub struct DataTrackFrame { /* private fields */ }
A frame published on a data track, consisting of a payload and optional metadata.

Examples

Create a frame from a Vec payload:

let some_payload = vec![0xFA; 256];
let frame: DataTrackFrame = some_payload.into();

assert_eq!(frame.payload().len(), 256);

Implementations

Source

impl DataTrackFrame

pub fn payload(&self) -> Bytes

Returns the frame’s payload.

pub fn user_timestamp(&self) -> Option<u64>

Returns the frame’s user timestamp, if one is associated.

pub fn duration_since_timestamp(&self) -> Option<Duration>

If the frame has a user timestamp, calculate how long has passed relative to the current system time.

If a timestamp is present, it is assumed it is a UNIX timestamp in milliseconds (as can be set with Self::with_user_timestamp_now on the publisher side). If the timestamp is invalid or not present, the result is none.

Source

impl DataTrackFrame

pub fn new(payload: impl Into<Bytes>) -> Self

Creates a frame from the given payload.

pub fn with_user_timestamp(self, value: u64) -> Self

Associates a user timestamp with the frame.

pub fn with_user_timestamp_now(self) -> Self

Associates the current Unix timestamp (in milliseconds) with the frame.