pub struct DataTrackInfo { /* private fields */ }Expand description
Information about a published data track.
Implementations
Sourceimpl DataTrackInfo
impl DataTrackInfo
Sourcepub fn sid(&self) -> DataTrackSid
pub fn sid(&self) -> DataTrackSid
Unique track identifier assigned by the SFU.
This identifier may change if a reconnect occurs. Use Self::name if a
stable identifier is needed.
Sourcepub fn uses_e2ee(&self) -> bool
pub fn uses_e2ee(&self) -> bool
Whether or not frames sent on the track use end-to-end encryption.
Sourcepub fn schema(&self) -> Option<&DataTrackSchemaId>
pub fn schema(&self) -> Option<&DataTrackSchemaId>
Schema associated with frames sent on the track.
Returns None if the publisher did not associate a
DataTrackSchemaId with the track.
Sourcepub fn frame_encoding(&self) -> Option<&DataTrackFrameEncoding>
pub fn frame_encoding(&self) -> Option<&DataTrackFrameEncoding>
Encoding of frames sent on the track.
Returns None if the publisher did not specify a
DataTrackFrameEncoding for the track.