pub struct DataTrackOptions { /* private fields */ }Expand description
Options for publishing a data track.
Examples
Create options for publishing a track named “my_track”:
let options = DataTrackOptions::new("my_track");Implementations
Sourceimpl DataTrackOptions
impl DataTrackOptions
Sourcepub fn new(name: impl Into<String>) -> Self
pub fn new(name: impl Into<String>) -> Self
Creates options with the given track name.
The track name is used to identify the track to other participants.
Requirements
- Must not be empty
- Must be unique per publisher
Sourcepub fn with_schema(self, schema: DataTrackSchemaId) -> Self
pub fn with_schema(self, schema: DataTrackSchemaId) -> Self
Sets the schema associated with frames sent on the track.
Sourcepub fn with_frame_encoding(self, encoding: DataTrackFrameEncoding) -> Self
pub fn with_frame_encoding(self, encoding: DataTrackFrameEncoding) -> Self
Sets the encoding of frames sent on the track.