pub struct DataTrackSubscribeOptions { /* private fields */ }Expand description
Options for subscribing to a data track.
Examples
Specify a custom buffer size:
let options = DataTrackSubscribeOptions::default()
.with_buffer_size(128); // Buffer 128 frames internally
Implementations
Sourceimpl DataTrackSubscribeOptions
impl DataTrackSubscribeOptions
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates subscribe options with default values.
Equivalent to Self::default.
Sourcepub fn buffer_size(&self) -> usize
pub fn buffer_size(&self) -> usize
Returns the maximum number of received frames buffered internally.
Sourcepub fn with_buffer_size(self, frames: usize) -> Self
pub fn with_buffer_size(self, frames: usize) -> Self
Sets the maximum number of received frames buffered internally.
Zero is not a valid buffer size; if a value of zero is provided, it will be clamped to one.
Note: if there is already an active subscription for a given track, specifying a different buffer size when obtaining a new subscription will have no effect.