pub struct PushFrameError { /* private fields */ }Expand description
Frame could not be pushed to a data track.
Implementations
Sourceimpl PushFrameError
impl PushFrameError
Sourcepub fn reason(&self) -> PushFrameErrorReason
pub fn reason(&self) -> PushFrameErrorReason
Returns the reason the frame could not be pushed.
Sourcepub fn into_frame(self) -> DataTrackFrame
pub fn into_frame(self) -> DataTrackFrame
Consumes the error and returns the frame that couldn’t be pushed.
This may be useful for implementing application-specific retry logic.