pub struct Manager { /* private fields */ }Expand description
An actor that manages the state of data tracks published by the local participant.
Implementations
Sourceimpl Manager
impl Manager
Sourcepub fn new(options: ManagerOptions) -> (Self, ManagerInput, ManagerOutput)
pub fn new(options: ManagerOptions) -> (Self, ManagerInput, ManagerOutput)
Creates a new manager.
Returns a tuple containing the following:
- The manager itself to be spawned by the caller (see
Manager::run). - Channel for sending
InputEvents to be processed by the manager. - Stream for receiving
OutputEvents produced by the manager.
Sourcepub async fn run(self)
pub async fn run(self)
Run the manager task, consuming self.
The manager will continue running until receiving InputEvent::Shutdown.