pub struct TrackPublished {
pub track: RemoteDataTrack,
}Expand description
A track has been published by a remote participant and is available to be subscribed to.
Emit a public event to deliver the track to the user, allowing them to subscribe
with RemoteDataTrack::subscribe if desired.
Fields
track: RemoteDataTrackTrack that was published.