Public APIs re-exported by client SDKs.
Structs
- Data
Track - Track for communicating application-specific data between participants in room.
- Data
Track Frame - A frame published on a data track, consisting of a payload and optional metadata.
- Data
Track Info - Information about a published data track.
- Data
Track Options - Options for publishing a data track.
- Data
Track Sid - SFU-assigned identifier uniquely identifying a data track.
- Data
Track SidError - Data
Track Stream - A stream of
DataTrackFrames received from aRemoteDataTrack. - Data
Track Subscribe Options - Options for subscribing to a data track.
- Internal
Error - Internal data track error.
- Local
- Marker type indicating a
DataTrackbelongs to the local participant. - Push
Frame Error - Frame could not be pushed to a data track.
- Remote
- Marker type indicating a
DataTrackbelongs to a remote participant.
Enums
- Data
Track Subscribe Error - Publish
Error - An error that can occur when publishing a data track.
- Push
Frame Error Reason - Reason why a data track frame could not be pushed.
Type Aliases
- Local
Data Track - Data track published by the local participant.
- Remote
Data Track - Data track published by a remote participant.