#[non_exhaustive]pub enum DataTrackSchemaEncoding {
Protobuf,
Flatbuffer,
Ros1Msg,
Ros2Msg,
Ros2Idl,
OmgIdl,
JsonSchema,
Other,
Custom(String),
}Expand description
Encoding used for a schema definition.
Identifies the interface definition language the schema is written in (e.g. a
.proto file for Protobuf). This in turn dictates the wire format of the
frames the schema describes, captured by DataTrackFrameEncoding.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Protobuf
Protocol Buffer IDL, describes Protobuf encoded frames.
Flatbuffer
FlatBuffer IDL, describes Flatbuffer encoded frames.
Ros1Msg
ROS 1 Message, describes Ros1 encoded frames.
Ros2Msg
ROS 2 Message, describes Cdr encoded frames.
Ros2Idl
ROS 2 IDL, describes Cdr encoded frames.
OmgIdl
OMG IDL, describes Cdr encoded frames.
JsonSchema
JSON Schema, describes Json encoded frames.
Other
Another well-known encoding not known to this client version.
Custom(String)
An application-specific encoding identified by the contained string.
Prefer using one of the well-known encodings unless the format is not enumerated. The identifier must be non-empty and not exceed the server’s length limit.