pub struct DataTrackFrame { /* private fields */ }Expand description
Implementations
Sourceimpl DataTrackFrame
impl DataTrackFrame
Sourcepub fn user_timestamp(&self) -> Option<u64>
pub fn user_timestamp(&self) -> Option<u64>
Returns the frame’s user timestamp, if one is associated.
Sourcepub fn duration_since_timestamp(&self) -> Option<Duration>
pub fn duration_since_timestamp(&self) -> Option<Duration>
If the frame has a user timestamp, calculate how long has passed relative to the current system time.
If a timestamp is present, it is assumed it is a UNIX timestamp in milliseconds
(as can be set with Self::with_user_timestamp_now on the publisher side).
If the timestamp is invalid or not present, the result is none.
Sourceimpl DataTrackFrame
impl DataTrackFrame
Sourcepub fn with_user_timestamp(self, value: u64) -> Self
pub fn with_user_timestamp(self, value: u64) -> Self
Associates a user timestamp with the frame.
Sourcepub fn with_user_timestamp_now(self) -> Self
pub fn with_user_timestamp_now(self) -> Self
Associates the current Unix timestamp (in milliseconds) with the frame.