pub enum InputEvent {
PublishRequest(PublishRequest),
PublishCancelled(PublishCancelled),
QueryPublished(QueryPublished),
UnpublishRequest(UnpublishRequest),
SfuPublishResponse(SfuPublishResponse),
SfuUnpublishResponse(SfuUnpublishResponse),
RepublishTracks,
Shutdown,
}Expand description
An external event handled by Manager.
Variants
PublishRequest(PublishRequest)
PublishCancelled(PublishCancelled)
QueryPublished(QueryPublished)
UnpublishRequest(UnpublishRequest)
SfuPublishResponse(SfuPublishResponse)
SfuUnpublishResponse(SfuUnpublishResponse)
RepublishTracks
Republish all tracks.
This must be sent after a full reconnect in order for existing publications to be recognized by the SFU. Each republished track will be assigned a new SID.
Shutdown
Shutdown the manager and all associated tracks.